@@ -1,4 +1,4 @@
-"""QASM interface for qoqo.
+"""QASM interface and backend for qoqo.
 
 Translates qoqo operations and circuits to QASM operations via the interface,
 and Create a Qasm file with QasmBackend.
